import java.io.File;

import org.gradle.api.GradleException;
import org.gradle.api.Project;
import org.gradle.api.internal.ConventionTask;

/**
 * Provides some shared functionality for other Cobertura classes
 * 
 * @author Phil Messenger
 *
 */
public abstract class AbstractCoberturaTask extends ConventionTask
{

	protected String COBERTURA_INSTRUMENT_CLASS = "net.sourceforge.cobertura.instrument.Main";
	protected String COBERTURA_REPORT_CLASS = "net.sourceforge.cobertura.reporting.Main";
	
	public AbstractCoberturaTask(Project project, String name)
	{
		super(project, name);
	}

	/**
	 * Build the classpath required to execute the Cobertura command line utilities
	 * 
	 * @return
	 */
	protected String[] getCoberturaClasspath()
	{
		
		File gradleLibs = new File( getProject().getBuild().getGradleHomeDir() ,"lib" );
		
		String[] path = new String[2];
		
		path[0] = gradleLibs.getPath() + "/*";
		
		if(! gradleLibs.exists())
		{
			throw new GradleException("Can't find the gradle libs directory");
		}
		
		for(File file : gradleLibs.listFiles())
		{
	
			if(file.getName().startsWith("cobertura"))
			{
				path[1] = file.getPath();
				
				getLogger().info("Cobertura jar: {}", file.getPath());
				
				break;
			}
		}
	
		if(path[1] == null)
		{
			throw new GradleException("Can't find Cobertura library. Ensure it is in GRADLE_HOME/lib");
		}
		
		return path;
	}

}
